==> jc-1.4.0.tar.gz: org/dellroad/jc/cgen/analysis/TypeAnalysis.h <==
// public class org.dellroad.jc.cgen.analysis.TypeAnalysis

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3b9063e6c6371e83 org_dellroad_jc_cgen_analysis_TypeAnalysis

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_dellroad_jc_cgen_analysis_TypeAnalysis_H_
#define _JC_org_dellroad_jc_cgen_analysis_TypeAnalysis_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Local$object;
struct _jc_soot_RefLikeType$object;
struct _jc_soot_Unit$object;
struct _jc_soot_jimple_AbstractJimpleValueSwitch$object;
struct _jc_soot_toolkits_scalar_LocalDefs$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$sub_refs	_jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$sub_refs;
typedef struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$sub_nonrefs	_jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$refs	_jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$refs;
typedef struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$nonrefs	_jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$object	_jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$object;

typedef const struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$vmethods	_jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$vmethods;
typedef const struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$vtable	_jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$vtable;
typedef const struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$vtype	_jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$vtype;

// Constructors
extern void _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$method$_init$bb84927231faab90(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_soot_RefLikeType$object *_jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$method$getExactType$02c12014361a201e(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$object *, struct _jc_object *, struct _jc_object *);
extern void _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$object *);

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$method_info$getExactType$02c12014361a201e;
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$vmethods {
	struct _jc_soot_RefLikeType$object	*(*getExactType$02c12014361a201e)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$object *, struct _jc_object *, struct _jc_object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$object *);
};

// Vtable
struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$vmethods	org_dellroad_jc_cgen_analysis_TypeAnalysis;
};

// Vtype
struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$sub_refs {
	struct _jc_object	*localDefs;
	struct _jc_soot_jimple_AbstractJimpleValueSwitch$object	*vs;
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$refs {
    _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$sub_refs	org_dellroad_jc_cgen_analysis_TypeAnalysis;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$sub_nonrefs	org_dellroad_jc_cgen_analysis_TypeAnalysis;
};

// Object instance structure
struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$object {
	_jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$vtype	*vtype;
	_jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$vtype _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_cgen_analysis_TypeAnalysis, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$class_object;

#endif	/* _JC_org_dellroad_jc_cgen_analysis_TypeAnalysis_H_ */

==> jc-1.4.6.tar.gz: org/dellroad/jc/cgen/analysis/TypeAnalysis.h <==
// public class org.dellroad.jc.cgen.analysis.TypeAnalysis

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3b9063e6c6371e83 org_dellroad_jc_cgen_analysis_TypeAnalysis

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_dellroad_jc_cgen_analysis_TypeAnalysis_H_
#define _JC_org_dellroad_jc_cgen_analysis_TypeAnalysis_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Local$object;
struct _jc_soot_RefLikeType$object;
struct _jc_soot_Unit$object;
struct _jc_soot_jimple_AbstractJimpleValueSwitch$object;
struct _jc_soot_toolkits_scalar_LocalDefs$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$sub_refs	_jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$sub_refs;
typedef struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$sub_nonrefs	_jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$refs	_jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$refs;
typedef struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$nonrefs	_jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$object	_jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$object;

typedef const struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$vmethods	_jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$vmethods;
typedef const struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$vtable	_jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$vtable;
typedef const struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$vtype	_jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$vtype;

// Constructors
extern void _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$method$_init$bb84927231faab90(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_soot_RefLikeType$object *_jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$method$getExactType$02c12014361a201e(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$method_info$getExactType$02c12014361a201e;
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$vmethods {
	struct _jc_soot_RefLikeType$object	*(*getExactType$02c12014361a201e)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$vmethods	org_dellroad_jc_cgen_analysis_TypeAnalysis;
};

// Vtype
struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$sub_refs {
	struct _jc_object	*localDefs;
	struct _jc_soot_jimple_AbstractJimpleValueSwitch$object	*vs;
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$refs {
    _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$sub_refs	org_dellroad_jc_cgen_analysis_TypeAnalysis;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$sub_nonrefs	org_dellroad_jc_cgen_analysis_TypeAnalysis;
};

// Object instance structure
struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$object {
	_jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$vtype	*vtype;
	_jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$vtype _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_cgen_analysis_TypeAnalysis, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$class_object;

#endif	/* _JC_org_dellroad_jc_cgen_analysis_TypeAnalysis_H_ */
